OwnedRepositoryManager

Struct OwnedRepositoryManager 

pub struct OwnedRepositoryManager {
    pub repo: RepositoryManager,
    /* private fields */
}
A repository manager which own full copy of a repo.

This is helpful when you need to perform a full-repo operation, such as ring check on tags, full-repo validation, etc.

Fields

repo: RepositoryManager

Implementations

Source

impl OwnedRepositoryManager

pub fn new(repo: RepositoryManager) -> RepoResult<Self>

pub fn album(&self, album_id: &Uuid) -> Option<&Album>

pub fn album_path(&self, album_id: &Uuid) -> Option<&Path>

pub fn albums(&self) -> &HashMap<Uuid, Album>

pub fn albums_iter(&self) -> impl Iterator<Item = &Album>

pub fn tag(&self, tag: &TagRef<'_>) -> Option<&Tag>

pub fn tags_iter(&self) -> impl Iterator<Item = &Tag>

pub fn tag_path<'a>(&'a self, tag: &'a TagRef<'_>) -> Option<&'a PathBuf>

pub fn child_tags<'me, 'tag>( &'me self, tag: &TagRef<'tag>, ) -> IndexSet<&'me TagRef<'tag>>
where 'tag: 'me,

pub fn albums_tagged_by<'me, 'tag>( &'me self, tag: &'me TagRef<'tag>, ) -> Option<&'me Vec<Uuid>>
where 'tag: 'me,

pub fn check_tags_loop<'me, 'tag>(&'me self) -> Option<Vec<&'me TagRef<'tag>>>
where 'me: 'tag,